using System;
using System.Drawing;
using MonoTouch.Foundation;
using MonoTouch.UIKit;
using Infragistics;
using System.Collections.Generic;
using MonoTouch.ObjCRuntime;

namespace StackedBarExample
{

	public class DataModel : NSObject
	{
		[Export("Label")]
		public string Label { get; set; }
		[Export("Value1")]
		public float Value1 { get; set; }
		[Export("Value2")]
		public float Value2 { get; set; }
		[Export("Value3")]
		public float Value3 { get; set; }
	}

	public partial class StackedBarExampleViewController : UIViewController
	{

		IGChartView _chartView;
		IGStackedSeriesDataSourceHelper _stackedChartDataSourceHelper;
		IGLegend _legend;
		List<NSObject> _data;

		static bool UserInterfaceIdiomIsPhone {
			get { return UIDevice.CurrentDevice.UserInterfaceIdiom == UIUserInterfaceIdiom.Phone; }
		}

		public StackedBarExampleViewController ()
			: base (UserInterfaceIdiomIsPhone ? "StackedBarExampleViewController_iPhone" : "StackedBarExampleViewController_iPad", null)
		{
		}

		public override void DidReceiveMemoryWarning ()
		{
			// Releases the view if it doesn't have a superview.
			base.DidReceiveMemoryWarning ();
			
			// Release any cached data, images, etc that aren't in use.
		}

		public override void ViewDidLoad ()
		{
			base.ViewDidLoad ();
			
			// Perform any additional setup after loading the view, typically from a nib.


			this.PopulateData();
			RectangleF bounds = new RectangleF(0, 0, this.View.Frame.Size.Width, this.View.Frame.Size.Height);
			_chartView = new IGChartView(bounds);
			_chartView.BackgroundColor = UIColor.White;



			List<NSString> valueList = new List<NSString> ();
			valueList.Add (new NSString("Value1"));
			valueList.Add (new NSString("Value2"));
			valueList.Add (new NSString("Value3"));

			_stackedChartDataSourceHelper = new IGStackedSeriesDataSourceHelper(  _data.ToArray(), 
			                                                                   
			                                                                 
			                                                                    valueList.ToArray());
			_chartView.AddStackedSeries(new Class(typeof(IGStackedBarSeries)), "series", _stackedChartDataSourceHelper, "xAxis", "yAxis");
			(this.View).AddSubview(_chartView);
			_legend = new IGLegend(IGChartLegendType.IGChartLegendTypeSeries);
			_legend.Frame = new RectangleF(20, 20, 100, 100);
			_chartView.Legend = _legend;
			(this.View).AddSubview(_legend);
		}

		public override bool ShouldAutorotateToInterfaceOrientation (UIInterfaceOrientation toInterfaceOrientation)
		{
			// Return true for supported orientations
			if (UserInterfaceIdiomIsPhone) {
				return (toInterfaceOrientation != UIInterfaceOrientation.PortraitUpsideDown);
			} else {
				return true;
			}
		}


		void PopulateData()
		{
			_data = new List<NSObject>();
			for (int i = 0; i < 10; i++) {
				DataModel item = new DataModel();
				item.Value1 = new Random((int)DateTime.Now.Ticks).Next(100);
				item.Value2 = new Random((int)DateTime.Now.Ticks).Next(100);
				item.Value3 = new Random((int)DateTime.Now.Ticks).Next(100);
				item.Label = string.Format ("Label {0}", i);
				_data.Add(item);
			}      
		}
	}
}

